@@ -27,25 +27,32 @@
 #define PGrnEqualStrategyNumber			3	/* operator = */
 #define PGrnGreaterEqualStrategyNumber	4	/* operator >= */
 #define PGrnGreaterStrategyNumber		5	/* operator > */
+#define PGrnLikeStrategyNumber			6	/* operator ~~ (LIKE) */
 #define PGrnContainStrategyNumber		7	/* operator %% (@ in Groonga) */
 #define PGrnQueryStrategyNumber			8	/* operator @@ (Groonga query) */
 
 /* Groonga support functions */
-#define PGrnTypeOfProc					1
-#define PGrnGetValueProc				2
+#define PGrnGetValueProc				1
+#define PGrnGetQueryProc				2
 
 /* file and table names */
 #define PGrnDatabaseBasename			"pgrn"
-#define PGrnIDsTableNamePrefix			"IDs"
-#define PGrnIDsTableNameFormat			PGrnIDsTableNamePrefix "%u"
-#define PGrnLexiconNameFormat			"Lexicon%u"
+#define PGrnSourcesTableNamePrefix		"Sources"
+#define PGrnSourcesTableNameFormat		PGrnSourcesTableNamePrefix "%u"
+#define PGrnLexiconNameFormat			"Lexicon%u_%u"
 #define PGrnIndexColumnName				"index"
 
 /* in pgroonga.c */
 extern void PGDLLEXPORT _PG_init(void);
 
+extern Datum PGDLLEXPORT pgroonga_score(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_table_name(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_command(PG_FUNCTION_ARGS);
+
 extern Datum PGDLLEXPORT pgroonga_contain_text(PG_FUNCTION_ARGS);
-extern Datum PGDLLEXPORT pgroonga_contain_bpchar(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_contain_text_array(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_contain_varchar(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_contain_varchar_array(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_match(PG_FUNCTION_ARGS);
 
 extern Datum PGDLLEXPORT pgroonga_insert(PG_FUNCTION_ARGS);
@@ -62,11 +69,10 @@ extern Datum PGDLLEXPORT pgroonga_costestimate(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_options(PG_FUNCTION_ARGS);
 
 /* in groonga_types.c */
-int pgroonga_bpchar_size(const BpChar *bpchar);
-
-extern Datum PGDLLEXPORT pgroonga_typeof(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_get_text(PG_FUNCTION_ARGS);
-extern Datum PGDLLEXPORT pgroonga_get_bpchar(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_get_text_array(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_get_varchar(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_get_varchar_array(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_get_bool(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_get_int2(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_get_int4(PG_FUNCTION_ARGS);
